Debugging and Performance
==========================

This section contains resources to help you debug and understand performance.


.. toctree::
   :maxdepth: 1

   how-to/debug.rst
   Visualize task graphs <graphviz.rst>
   Dashboard <dashboard.rst> 
   diagnostics-local.rst
   diagnostics-distributed.rst
   Phases of computation <phases-of-computation.rst>
